@@ -13,7 +13,8 @@ cherries <- function(input_obj, normalization = "none") {
   normalization <- check_normalization_key(normalization)
   check_tree(input_obj,
              require_binary = TRUE,
-             require_ultrametric = FALSE)
+             require_ultrametric = FALSE,
+             require_rooted = FALSE)
 
   num_cherries <- 0
 
