@@ -5,13 +5,18 @@
 #' @param input_obj phylo object or ltable
 #' @param normalization if true, the number of steps taken is normalized by tree
 #' size, by dividing by the maximum number of moves required to move from a
-#' fully balanced to a fully imbalanced tree, which is N - log2(N) - 1, where
-#' N is the number of extant tips.
+#' fully balanced to a fully imbalanced tree, which is \eqn{N - log2(N) - 1},
+#' where N is the number of extant tips.
 #' @return required number of moves
 #' @export
 imbalance_steps <- function(input_obj,
                             normalization = FALSE) {
 
+  check_tree(input_obj,
+             require_binary = TRUE,
+             require_ultrametric = TRUE,
+             require_rooted = TRUE)
+
   if (inherits(input_obj, "phylo")) {
     input_obj <- treestats::phylo_to_l(input_obj)
   }
