@@ -15,7 +15,8 @@ max_betweenness <- function(phy, normalization = "none") {
   normalization <- check_normalization_key(normalization)
   check_tree(phy,
              require_binary = TRUE,
-             require_ultrametric = FALSE)
+             require_ultrametric = FALSE,
+             require_rooted = TRUE)
 
   if (inherits(phy, "matrix")) {
     betweenness_stat <- calc_max_betweenness_ltable_cpp(phy)
