@@ -19,7 +19,8 @@ sackin <- function(phy, normalization = "none") {
 
   check_tree(phy,
              require_binary = TRUE,
-             require_ultrametric = FALSE)
+             require_ultrametric = FALSE,
+             require_rooted = TRUE)
 
   if (inherits(phy, "matrix")) {
     return(calc_sackin_ltable_cpp(phy, normalization))
