@@ -13,7 +13,8 @@
 stairs <- function(input_obj) {
   check_tree(input_obj,
              require_binary = TRUE,
-             require_ultrametric = FALSE)
+             require_ultrametric = FALSE,
+             require_rooted = TRUE)
 
   if (inherits(input_obj, "matrix")) {
     return(stairs_ltable_cpp(input_obj))
@@ -27,9 +28,9 @@ stairs <- function(input_obj) {
 #' Stairs2 index
 #' @description Calculates the stairs2 measure, from the phyloTop package. The
 #' stairs2 reflects the imbalance at each node, where it represents the average
-#' across measure at each node, the measure being min(l, r) / max(l, r), where
-#' l and r reflect the number of tips connected at the left (l) and right (r)
-#' daughter.
+#' across measure at each node, the measure being \eqn{min(L, R) / max(L, R)},
+#' where L and R reflect the number of tips connected at the left (L) and right
+#' (R) daughter.
 #' @param input_obj phylo object or ltable
 #' @return number of stairs
 #' @references Norström, Melissa M., et al. "Phylotempo: a set of r scripts for
@@ -40,7 +41,8 @@ stairs <- function(input_obj) {
 stairs2 <- function(input_obj) {
   check_tree(input_obj,
              require_binary = TRUE,
-             require_ultrametric = FALSE)
+             require_ultrametric = FALSE,
+             require_rooted = TRUE)
 
   if (inherits(input_obj, "matrix")) {
     return(stairs2_ltable_cpp(input_obj))
