@@ -1,4 +1,4 @@
-// Copyright 2022 - 2024 Thijs Janzen
+// Copyright 2022 - 2025 Thijs Janzen
 // This program is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation, either version 3 of the License, or
@@ -15,7 +15,8 @@
 
 #include <vector>
 #include <array>
-#include <Rcpp.h>
+#include <string>
+#include <RcppArmadillo.h>
 
 #include "util.h"     // NOLINT [build/include_subdir]
 #include "colless.h"  // NOLINT [build/include_subdir]
