@@ -27,6 +27,14 @@ test_that("usage", {
   testthat::expect_equal(a1, a2)
 })
 
+test_that("unrooted", {
+  set.seed(42)
+  focal_tree <- ape::rphylo(n = 100, birth = 1, death = 0)
+  a1 <- treestats::mntd(focal_tree)
+  a2 <- treestats::mntd(ape::unroot(focal_tree))
+  testthat::expect_equal(a1, a2)
+})
+
 test_that("wrong_object", {
   testthat::expect_error(
     treestats::mntd(10),
