@@ -32,7 +32,18 @@ test_that("usage", {
 
   # use very small tree to trigger use of complete method:
   focal_tree <- ape::rphylo(n = 6, birth = 1, death = 0)
-  rho <- treestats::pigot_rho(focal_tree)
+  # compare to ltab, as this is always the same method
+  ltab <- treestats::phylo_to_l(focal_tree)
+  testthat::expect_equal(treestats::pigot_rho(focal_tree),
+                         treestats::pigot_rho(ltab))
+
+  # and very large tree to trigger other method:
+  focal_tree <- ape::rphylo(n = 300, birth = 1, death = 0)
+  # compare to ltab, as this is always the same method
+  ltab <- treestats::phylo_to_l(focal_tree)
+  testthat::expect_equal(treestats::pigot_rho(focal_tree),
+                         treestats::pigot_rho(ltab))
+
 })
 
 test_that("wrong_object", {
